using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

namespace MakeWebPictures
{
	public enum CodecChoice 
	{
		jpeg,
		png
	};

	public class GraphicsSettings
	{
		public CodecChoice Codec;
		public int Width;
		public int Height;
		public int Quality;

		public GraphicsSettings(CodecChoice codec, int width, int height, int quality) 
		{
			this.Codec = codec;
			this.Width = width;
			this.Height = height;
			this.Quality = quality;
		}

		public string GetSettingsAsText()
		{
			string txt;

			txt = (Codec == CodecChoice.jpeg) ? "JPEG" : "PNG";
			txt += ", ";
			txt += Convert.ToString(Width);
			txt += "x";
			txt += Convert.ToString(Height);
			if (Codec == CodecChoice.jpeg) 
			{
				txt += ", Q: " + Convert.ToString(Quality);
			}
			return txt;
		}


	}

	/// <summary>
	/// Summary description for GraphicsSettings.
	/// </summary>
	public class GraphicsSettingsDialog : System.Windows.Forms.Form
	{
		private System.Windows.Forms.RadioButton jpegRadioButton;
		private System.Windows.Forms.RadioButton pngRadioButton;
		private System.Windows.Forms.TextBox maxHeightTextBox;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.Label label4;
		private System.Windows.Forms.TextBox maxWidthTextBox;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Button cancelButton;
		private System.Windows.Forms.Button okButton;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		private System.Windows.Forms.TextBox qualityTextBox;

		public GraphicsSettingsDialog(string title, GraphicsSettings g)
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			this.Text = title;
			this.jpegRadioButton.Checked = g.Codec == CodecChoice.jpeg;
			this.pngRadioButton.Checked = g.Codec == CodecChoice.png;
			this.maxWidthTextBox.Text = Convert.ToString(g.Width);
			this.maxHeightTextBox.Text = Convert.ToString(g.Height);
			this.qualityTextBox.Text = Convert.ToString(g.Quality);
			//
			// TODO: Add any constructor code after InitializeComponent call
			//
		}

		public GraphicsSettings GetSettings() 
		{
			GraphicsSettings g = new GraphicsSettings(this.jpegRadioButton.Checked ? CodecChoice.jpeg : CodecChoice.png,
				Convert.ToInt32(this.maxWidthTextBox.Text),
				Convert.ToInt32(this.maxHeightTextBox.Text),
				Convert.ToInt32(this.qualityTextBox.Text));
			return g;
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.jpegRadioButton = new System.Windows.Forms.RadioButton();
			this.pngRadioButton = new System.Windows.Forms.RadioButton();
			this.maxHeightTextBox = new System.Windows.Forms.TextBox();
			this.label3 = new System.Windows.Forms.Label();
			this.label4 = new System.Windows.Forms.Label();
			this.maxWidthTextBox = new System.Windows.Forms.TextBox();
			this.qualityTextBox = new System.Windows.Forms.TextBox();
			this.label1 = new System.Windows.Forms.Label();
			this.cancelButton = new System.Windows.Forms.Button();
			this.okButton = new System.Windows.Forms.Button();
			this.SuspendLayout();
			// 
			// jpegRadioButton
			// 
			this.jpegRadioButton.Checked = true;
			this.jpegRadioButton.Location = new System.Drawing.Point(24, 32);
			this.jpegRadioButton.Name = "jpegRadioButton";
			this.jpegRadioButton.TabIndex = 0;
			this.jpegRadioButton.TabStop = true;
			this.jpegRadioButton.Text = "JPEG";
			this.jpegRadioButton.CheckedChanged += new System.EventHandler(this.compressorChanged);
			// 
			// pngRadioButton
			// 
			this.pngRadioButton.Location = new System.Drawing.Point(24, 72);
			this.pngRadioButton.Name = "pngRadioButton";
			this.pngRadioButton.TabIndex = 1;
			this.pngRadioButton.Text = "PNG";
			// 
			// maxHeightTextBox
			// 
			this.maxHeightTextBox.Location = new System.Drawing.Point(144, 160);
			this.maxHeightTextBox.Name = "maxHeightTextBox";
			this.maxHeightTextBox.TabIndex = 2;
			this.maxHeightTextBox.Text = "600";
			this.maxHeightTextBox.Validating += new System.ComponentModel.CancelEventHandler(this.numberTextBox_Validating);
			// 
			// label3
			// 
			this.label3.Location = new System.Drawing.Point(32, 160);
			this.label3.Name = "label3";
			this.label3.Size = new System.Drawing.Size(96, 24);
			this.label3.TabIndex = 8;
			this.label3.Text = "Maximum height";
			// 
			// label4
			// 
			this.label4.Location = new System.Drawing.Point(32, 120);
			this.label4.Name = "label4";
			this.label4.Size = new System.Drawing.Size(96, 24);
			this.label4.TabIndex = 7;
			this.label4.Text = "Maximum width";
			// 
			// maxWidthTextBox
			// 
			this.maxWidthTextBox.Location = new System.Drawing.Point(144, 120);
			this.maxWidthTextBox.Name = "maxWidthTextBox";
			this.maxWidthTextBox.TabIndex = 1;
			this.maxWidthTextBox.Text = "800";
			this.maxWidthTextBox.Validating += new System.ComponentModel.CancelEventHandler(this.numberTextBox_Validating);
			// 
			// qualityTextBox
			// 
			this.qualityTextBox.Location = new System.Drawing.Point(144, 200);
			this.qualityTextBox.Name = "qualityTextBox";
			this.qualityTextBox.TabIndex = 3;
			this.qualityTextBox.Text = "75";
			this.qualityTextBox.Validating += new System.ComponentModel.CancelEventHandler(this.numberTextBox_Validating);
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(32, 200);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(96, 24);
			this.label1.TabIndex = 7;
			this.label1.Text = "Quality (0-100)";
			// 
			// cancelButton
			// 
			this.cancelButton.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.cancelButton.Location = new System.Drawing.Point(32, 256);
			this.cancelButton.Name = "cancelButton";
			this.cancelButton.Size = new System.Drawing.Size(80, 32);
			this.cancelButton.TabIndex = 5;
			this.cancelButton.Text = "Cancel";
			// 
			// okButton
			// 
			this.okButton.Location = new System.Drawing.Point(160, 256);
			this.okButton.Name = "okButton";
			this.okButton.Size = new System.Drawing.Size(80, 32);
			this.okButton.TabIndex = 4;
			this.okButton.Text = "OK";
			this.okButton.Click += new System.EventHandler(this.okButton_Click);
			// 
			// GraphicsSettingsDialog
			// 
			this.AcceptButton = this.okButton;
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.CancelButton = this.cancelButton;
			this.ClientSize = new System.Drawing.Size(298, 320);
			this.Controls.AddRange(new System.Windows.Forms.Control[] {
																		  this.cancelButton,
																		  this.maxHeightTextBox,
																		  this.label3,
																		  this.label4,
																		  this.maxWidthTextBox,
																		  this.pngRadioButton,
																		  this.jpegRadioButton,
																		  this.qualityTextBox,
																		  this.label1,
																		  this.okButton});
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedToolWindow;
			this.MaximizeBox = false;
			this.MinimizeBox = false;
			this.Name = "GraphicsSettingsDialog";
			this.ShowInTaskbar = false;
			this.Text = "Graphics Settings";
			this.ResumeLayout(false);

		}
		#endregion

		private void compressorChanged(object sender, System.EventArgs e)
		{
		
		}

		private void numberTextBox_Validating(object sender, System.ComponentModel.CancelEventArgs e)
		{
			int tmp;
			try 
			{
				tmp = Convert.ToInt32(((System.Windows.Forms.TextBox)sender).Text);
				if (tmp < 1 || ( ( ((System.Windows.Forms.TextBox)sender) == qualityTextBox) && tmp > 100 ) )
					e.Cancel = true;
			} 
			catch 
			{
				MessageBox.Show("Please enter a valid number");
				e.Cancel = true;
			}
		
		}

		private void okButton_Click(object sender, System.EventArgs e)
		{
			this.DialogResult = DialogResult.OK;
		}
	}
}
